Struct ZwlrOutputManagerV1
pub struct ZwlrOutputManagerV1 { /* private fields */ }wayland and Linux only.Expand description
output device configuration manager
This interface is a manager that allows reading and writing the current output device configuration.
Output devices that display pixels (e.g. a physical monitor or a virtual output in a window) are represented as heads. Heads cannot be created nor destroyed by the client, but they can be enabled or disabled and their properties can be changed. Each head may have one or more available modes.
Whenever a head appears (e.g. a monitor is plugged in), it will be advertised via the head event. Immediately after the output manager is bound, all current heads are advertised.
Whenever a head’s properties change, the relevant wlr_output_head events will be sent. Not all head properties will be sent: only properties that have changed need to.
Whenever a head disappears (e.g. a monitor is unplugged), a wlr_output_head.finished event will be sent.
After one or more heads appear, change or disappear, the done event will be sent. It carries a serial which can be used in a create_configuration request to update heads properties.
The information obtained from this protocol should only be used for output configuration purposes. This protocol is not designed to be a generic output property advertisement protocol for regular clients. Instead, protocols such as xdg-output should be used.
See also the Event enum for this interface.
Implementations
impl ZwlrOutputManagerV1
impl ZwlrOutputManagerV1
pub fn create_configuration<U, D>(
&self,
serial: u32,
qh: &QueueHandle<D>,
udata: U,
) -> ZwlrOutputConfigurationV1
pub fn create_configuration<U, D>( &self, serial: u32, qh: &QueueHandle<D>, udata: U, ) -> ZwlrOutputConfigurationV1
create a new output configuration object
Create a new output configuration object. This allows to update head properties.
pub fn stop(&self)
pub fn stop(&self)
stop sending events
Indicates the client no longer wishes to receive events for output configuration changes. However the compositor may emit further events, until the finished event is emitted.
The client must not send any more requests after this one.